@@ -1,5 +1,5 @@
 package Net::Whois::Raw::Common;
-$Net::Whois::Raw::Common::VERSION = '2.99';
+$Net::Whois::Raw::Common::VERSION = '2.99001';
 # ABSTRACT: Helper for Net::Whois::Raw.
 
 use Encode;
@@ -183,7 +183,8 @@ sub get_server {
                $Net::Whois::Raw::Data::servers{ 'NS' };
     }
     else {
-            my $cname = "$tld.whois-servers.net";
+            #my $cname = "$tld.whois-servers.net";
+            my $cname = "whois.nic.$tld";
         $srv = $Net::Whois::Raw::Data::servers{ $tld } || $cname;
     }
 
@@ -619,7 +620,7 @@ Net::Whois::Raw::Common - Helper for Net::Whois::Raw.
 
 =head1 VERSION
 
-version 2.99
+version 2.99001
 
 =head1 AUTHOR
 
