@@ -1,5 +1,5 @@
 package Net::Whois::Raw::Data;
-$Net::Whois::Raw::Data::VERSION = '2.99';
+$Net::Whois::Raw::Data::VERSION = '2.99001';
 # ABSTRACT: Config for Net::Whois::Raw.
 
 use utf8;
@@ -138,9 +138,9 @@ our %servers = qw(
     GOV             whois.dotgov.gov
     INFO            whois.afilias.net
     INT             whois.iana.org
-    JOBS            jobswhois.verisign-grs.com
+    JOBS            whois.nic.jobs
     MIL             whois.nic.mil
-    MOBI            whois.dotmobiregistry.net
+    MOBI            whois.afilias.net
     MUSEUM          whois.museum
     NAME            whois.nic.name
     NET             whois.crsnic.net
@@ -328,6 +328,7 @@ our %servers = qw(
     TATAR           whois.nic.tatar
     TOP             whois.nic.top
     TRADING         whois.nic.trading
+    TUBE            whois.nic.tube
     WIEN            whois.nic.wien
     UNO             whois.nic.uno
     XXX             whois.nic.xxx
@@ -338,6 +339,7 @@ our %servers = qw(
     KIM             whois.afilias.net
     BLUE            whois.afilias.net
     PET             whois.afilias.net
+    PROMO           whois.afilias.net
     BET             whois.afilias.net
 
     ACTOR           whois.unitedtld.com
@@ -452,7 +454,7 @@ our %servers = qw(
     KI  whois.nic.ki
     KR  whois.nic.or.kr
     KZ  whois.nic.kz
-    LA  whois.centralnic.com
+    LA  whois.nic.com
     LC  whois2.afilias-grs.net
     LI  whois.nic.li
     LT  whois.domreg.lt
@@ -744,6 +746,7 @@ our %servers = qw(
     UY.COM      whois.centralnic.com
     ZA.COM      whois.centralnic.com
 
+    ART         whois.centralnic.com
     BAR         whois.centralnic.com
     COLLEGE     whois.centralnic.com
     CONTACT     whois.centralnic.com
@@ -751,6 +754,7 @@ our %servers = qw(
     FAN         whois.centralnic.com
     FANS        whois.centralnic.com
     FEEDBACK    whois.centralnic.com
+    FORUM       whois.centralnic.com
     HOST        whois.centralnic.com
     INK         whois.centralnic.com
     LOVE        whois.centralnic.com
@@ -772,7 +776,6 @@ our %servers = qw(
     WEBSITE     whois.centralnic.com
     WIKI        whois.centralnic.com
     XYZ         whois.centralnic.com
-    TUBE        whois.nic.tube
 
     ORG.NS      whois.pir.org
     BIZ.NS      whois.biz
@@ -1029,7 +1032,7 @@ our %notfound = (
      # 'whois.yournamemonkey.com' -- need try again
     'whois.cnnic.net.cn'        => 'no matching record',
     'whois.nic.co'              => 'Not found: \S+',
-    'me.whois-servers.net'      => 'NOT FOUND',
+    'whois.nic.me'              => 'NOT FOUND',
     'whois.domain.kg'           => 'Data not found. This domain is available for registration.',
     'whois.nic.one'             => 'No Data Found',
 
@@ -2695,7 +2698,7 @@ Net::Whois::Raw::Data - Config for Net::Whois::Raw.
 
 =head1 VERSION
 
-version 2.99
+version 2.99001
 
 =head1 AUTHOR
 
